==> pyside-setup-opensource-src-6.2.12.zip: pyside-setup-opensource-src-6.2.12/sources/shiboken6/tests/samplebinding/exception_test.py <==
#!/usr/bin/env python
#
#############################################################################
##
## Copyright (C) 2018 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

import os
import sys
import unittest

from pathlib import Path
sys.path.append(os.fspath(Path(__file__).resolve().parents[1]))
from shiboken_paths import init_paths
init_paths()

from sample import ExceptionTest

class CppExceptionTest(unittest.TestCase):

    def testVoid(self):
        exceptionCount = 0
        et = ExceptionTest()

        et.voidThrowStdException(False)

        try:
            et.voidThrowStdException(True)
        except:
            exceptionCount += 1

        et.voidThrowInt(False)

        try:
            et.voidThrowInt(True)
        except:
            exceptionCount += 1

        self.assertEqual(exceptionCount, 2)

    def testReturnValue(self):
        exceptionCount = 0
        et = ExceptionTest()

        result = et.intThrowStdException(False);

        try:
            result = et.intThrowStdException(True);
        except:
            exceptionCount += 1

        result = et.intThrowInt(False);

        try:
            result = et.intThrowInt(True);
        except:
            exceptionCount += 1

        self.assertEqual(exceptionCount, 2)

if __name__ == '__main__':
    unittest.main()

==> pyside-setup-opensource-src-6.5.4.zip: pyside-setup-opensource-src-6.5.4/sources/shiboken6/tests/samplebinding/exception_test.py <==
#!/usr/bin/env python
# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0

import os
import sys
import unittest

from pathlib import Path
sys.path.append(os.fspath(Path(__file__).resolve().parents[1]))
from shiboken_paths import init_paths
init_paths()

from sample import ExceptionTest

class CppExceptionTest(unittest.TestCase):

    def testVoid(self):
        exceptionCount = 0
        et = ExceptionTest()

        et.voidThrowStdException(False)

        try:
            et.voidThrowStdException(True)
        except:
            exceptionCount += 1

        et.voidThrowInt(False)

        try:
            et.voidThrowInt(True)
        except:
            exceptionCount += 1

        self.assertEqual(exceptionCount, 2)

    def testReturnValue(self):
        exceptionCount = 0
        et = ExceptionTest()

        result = et.intThrowStdException(False);

        try:
            result = et.intThrowStdException(True);
        except:
            exceptionCount += 1

        result = et.intThrowInt(False);

        try:
            result = et.intThrowInt(True);
        except:
            exceptionCount += 1

        self.assertEqual(exceptionCount, 2)

        def testModifications(self):
            """PYSIDE-1995, test whether exceptions are propagated
               when return ownership modifications are generated."""
            exceptionCount = 0
            try:
                et = ExceptionTest.create(True);
            except:
                exceptionCount += 1
            self.assertEqual(exceptionCount, 1)


if __name__ == '__main__':
    unittest.main()
